@@ -7,6 +7,7 @@ use Cwd;
 use English qw(-no_match_vars);
 use UNIVERSAL::require;
 use File::Glob;
+use IO::Handle;
 
 use FusionInventory::Agent::Config;
 use FusionInventory::Agent::HTTP::Client::OCS;
@@ -21,7 +22,7 @@ use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Hostname;
 use FusionInventory::Agent::XML::Query::Prolog;
 
-our $VERSION = '2.1.9904';
+our $VERSION = '2.2.3';
 our $VERSION_STRING = 
     "FusionInventory unified agent for UNIX, Linux and MacOSX ($VERSION)";
 our $AGENT_STRING =
@@ -150,6 +151,18 @@ sub init {
         }
     }
 
+    # compute list of allowed tasks
+    my %available = $self->getAvailableTasks(disabledTasks => $config->{'no-task'});
+    my @tasks = keys %available;
+
+    $logger->debug("Available tasks:");
+    foreach my $task (keys %available) {
+        $logger->debug("- $task: $available{$task}");
+    }
+
+    $self->{tasks} = \@tasks;
+
+    # create HTTP interface
     if (($config->{daemon} || $config->{service}) && !$config->{'no-httpd'}) {
         FusionInventory::Agent::HTTP::Server->require();
         if ($EVAL_ERROR) {
@@ -178,12 +191,6 @@ sub init {
         }
     }
 
-    # compute list of allowed tasks
-    my %available = $self->getAvailableTasks(disabledTasks => $config->{'no-task'});
-    my @tasks = keys %available;
-
-    $self->{tasks} = \@tasks;
-
     $logger->debug("FusionInventory Agent initialised");
 }
 
@@ -211,6 +218,7 @@ sub _runTarget {
     if ($target->isa('FusionInventory::Agent::Target::Server')) {
         my $client = FusionInventory::Agent::HTTP::Client::OCS->new(
             logger       => $self->{logger},
+            timeout      => $self->{timeout},
             user         => $self->{config}->{user},
             password     => $self->{config}->{password},
             proxy        => $self->{config}->{proxy},
@@ -249,7 +257,35 @@ sub _runTarget {
 sub _runTask {
     my ($self, $target, $name, $response) = @_;
 
+    $self->{status} = "running task $name";
+
+    if ($self->{config}->{daemon} || $self->{config}->{service}) {
+        # server mode: run each task in a child process
+        if (my $pid = fork()) {
+            # parent
+            waitpid($pid, 0);
+        } else {
+            # child
+            die "fork failed: $ERRNO" unless defined $pid;
+
+            $self->{logger}->debug("running task $name in process $PID");
+            $self->_runTaskReal($target, $name, $response);
+            exit(0);
+        }
+    } else {
+        # standalone mode: run each task directly
+        $self->{logger}->debug("running task $name");
+        $self->_runTaskReal($target, $name, $response);
+    }
+}
+
+sub _runTaskReal {
+    my ($self, $target, $name, $response) = @_;
+
     my $class = "FusionInventory::Agent::Task::$name";
+
+    $class->require();
+
     my $task = $class->new(
         config       => $self->{config},
         confdir      => $self->{confdir},
@@ -264,40 +300,14 @@ sub _runTask {
         return;
     }
 
-    $self->{status} = "running task $name";
-
-    if ($self->{config}->{daemon} || $self->{config}->{service}) {
-        # daemon mode: run each task in a child process
-        if (my $pid = fork()) {
-            # parent
-            waitpid($pid, 0);
-        } else {
-            # child
-            die "fork failed: $ERRNO" unless defined $pid;
-
-            $self->{logger}->debug("running task $name in process $PID");
-            $task->run(
-                user         => $self->{config}->{user},
-                password     => $self->{config}->{password},
-                proxy        => $self->{config}->{proxy},
-                ca_cert_file => $self->{config}->{'ca-cert-file'},
-                ca_cert_dir  => $self->{config}->{'ca-cert-dir'},
-                no_ssl_check => $self->{config}->{'no-ssl-check'},
-            );
-            exit(0);
-        }
-    } else {
-        # standalone mode: run each task directly
-        $self->{logger}->debug("running task $name");
-        $task->run(
-            user         => $self->{config}->{user},
-            password     => $self->{config}->{password},
-            proxy        => $self->{config}->{proxy},
-            ca_cert_file => $self->{config}->{'ca-cert-file'},
-            ca_cert_dir  => $self->{config}->{'ca-cert-dir'},
-            no_ssl_check => $self->{config}->{'no-ssl-check'},
-        );
-    }
+    $task->run(
+        user         => $self->{config}->{user},
+        password     => $self->{config}->{password},
+        proxy        => $self->{config}->{proxy},
+        ca_cert_file => $self->{config}->{'ca-cert-file'},
+        ca_cert_dir  => $self->{config}->{'ca-cert-dir'},
+        no_ssl_check => $self->{config}->{'no-ssl-check'},
+    );
 }
 
 sub getToken {
@@ -318,7 +328,6 @@ sub getStatus {
 sub getAvailableTasks {
     my ($self, %params) = @_;
 
-    my $logger = $self->{logger};
     my %tasks;
     my %disabled  = map { lc($_) => 1 } @{$params{disabledTasks}};
 
@@ -334,23 +343,36 @@ sub getAvailableTasks {
 
         next if $disabled{lc($name)};
 
-        # check module
-        # todo: use a child process when running as a server to save memory
-        if (!$module->require()) {
-            $logger->debug2("module $module does not compile") if $logger;
-            next;
-        }
-        if (!$module->isa('FusionInventory::Agent::Task')) {
-            $logger->debug2("module $module is not a task") if $logger;
-            next;
+        my $version;
+        if ($self->{config}->{daemon} || $self->{config}->{service}) {
+            # server mode: check each task version in a child process
+            my ($reader, $writer);
+            pipe($reader, $writer);
+            $writer->autoflush(1);
+
+            if (my $pid = fork()) {
+                # parent
+                close $writer;
+                $version = <$reader>;
+                close $reader;
+                waitpid($pid, 0);
+            } else {
+                # child
+                die "fork failed: $ERRNO" unless defined $pid;
+
+                close $reader;
+                $version = $self->_getTaskVersion($module);
+                print $writer $version if $version;
+                close $writer;
+                exit(0);
+            }
+        } else {
+            # standalone mode: check each task version directly
+            $version = $self->_getTaskVersion($module);
         }
 
-        # retrieve version
-        my $version;
-        {
-            no strict 'refs';  ## no critic
-            $version = ${$module . '::VERSION'};
-        }
+        # no version means non-functionning task
+        next unless $version;
 
         $tasks{$name} = $version;
     }
@@ -358,6 +380,30 @@ sub getAvailableTasks {
     return %tasks;
 }
 
+sub _getTaskVersion {
+    my ($self, $module) = @_;
+
+    my $logger = $self->{logger};
+
+    if (!$module->require()) {
+        $logger->debug2("module $module does not compile: $@") if $logger;
+        return;
+    }
+
+    if (!$module->isa('FusionInventory::Agent::Task')) {
+        $logger->debug2("module $module is not a task") if $logger;
+        return;
+    }
+
+    my $version;
+    {
+        no strict 'refs';  ## no critic
+        $version = ${$module . '::VERSION'};
+    }
+
+    return $version;
+}
+
 sub _isAlreadyRunning {
     my ($self) = @_;
 
