@@ -60,8 +60,18 @@ sub run {
         );
     }
 
-    $self->_initModulesList();
-    $self->_feedInventory($inventory);
+    if (not $ENV{PATH}) {
+        # set a minimal PATH if none is set (#1129)
+        $ENV{PATH} = '/sbin:/usr/sbin:/bin:/usr/bin';
+        $self->{logger}->debug(
+            "PATH is not set, using /sbin:/usr/sbin:/bin:/usr/bin as default"
+        );
+    }
+
+    my %disabled = map { $_ => 1 } @{$self->{config}->{'no-category'}};
+
+    $self->_initModulesList(\%disabled);
+    $self->_feedInventory($inventory, \%disabled);
 
     if ($self->{target}->isa('FusionInventory::Agent::Target::Stdout')) {
         $self->_printInventory(
@@ -119,11 +129,10 @@ sub run {
 }
 
 sub _initModulesList {
-    my ($self) = @_;
+    my ($self, $disabled) = @_;
 
     my $logger = $self->{logger};
     my $config = $self->{config};
-    my $storage = $self->{storage};
 
     my @modules = __PACKAGE__->getModules('Input');
     die "no inventory module found" if !@modules;
@@ -155,11 +164,10 @@ sub _initModulesList {
             logger => $logger,
             timeout  => $config->{'backend-collect-timeout'},
             params => {
+                no_category   => $disabled,
                 datadir       => $self->{datadir},
                 logger        => $self->{logger},
                 registry      => $self->{registry},
-                no_software   => $self->{config}->{'no-software'},
-                no_printer    => $self->{config}->{'no-printer'},
                 scan_homedirs => $self->{config}->{'scan-homedirs'},
             }
         );
@@ -173,7 +181,7 @@ sub _initModulesList {
         $self->{modules}->{$module}->{done}    = 0;
         $self->{modules}->{$module}->{used}    = 0;
 
-        no strict 'refs'; ## no critic
+        no strict 'refs'; ## no critic (ProhibitNoStrict)
         $self->{modules}->{$module}->{runAfter} = [ 
             $parent ? $parent : (),
             ${$module . '::runAfter'} ? @${$module . '::runAfter'} : ()
@@ -182,7 +190,8 @@ sub _initModulesList {
 
     # second pass: disable fallback modules
     foreach my $module (@modules) {
-        no strict 'refs'; ## no critic
+        ## no critic (ProhibitProlongedStrictureOverride)
+        no strict 'refs'; ## no critic (ProhibitNoStrict)
 
         # skip modules already disabled
         next unless $self->{modules}->{$module}->{enabled};
@@ -198,15 +207,15 @@ sub _initModulesList {
             }
         }
 
-        unless ($failed) {
+        if ($failed) {
             $self->{modules}->{$module}->{enabled} = 0;
-            $logger->debug("module $module disabled: no depended module failed");
+            $logger->debug("module $module disabled because of $failed");
         }
     }
 }
 
 sub _runModule {
-    my ($self, $module, $inventory) = @_;
+    my ($self, $module, $inventory, $disabled) = @_;
 
     my $logger = $self->{logger};
 
@@ -225,7 +234,7 @@ sub _runModule {
         die "circular dependency between $module and $other_module"
             if $self->{modules}->{$other_module}->{used};
 
-        $self->_runModule($other_module, $inventory);
+        $self->_runModule($other_module, $inventory, $disabled);
     }
 
     $logger->debug("Running $module");
@@ -238,10 +247,9 @@ sub _runModule {
         params => {
             datadir       => $self->{datadir},
             inventory     => $inventory,
+            no_category   => $disabled,
             logger        => $self->{logger},
             registry      => $self->{registry},
-            no_software   => $self->{config}->{no_software},
-            no_printer    => $self->{config}->{no_printer},
             scan_homedirs => $self->{config}->{'scan-homedirs'},
         }
     );
@@ -277,8 +285,6 @@ sub _feedInventory {
 
     $inventory->computeLegacyValues();
     $inventory->computeChecksum();
-
-    $inventory->checkContent();
 }
 
 sub _injectContent {
@@ -359,4 +365,4 @@ FusionInventory::Agent::Task::Inventory - Inventory task for FusionInventory
 
 =head1 DESCRIPTION
 
-This task extract various hardware and software informations on the agent host.
+This task extract various hardware and software information on the agent host.
