@@ -44,7 +44,7 @@ sub doInventory {
     if (canRun('lsb_release')) {
         $OSName = getFirstMatch(
             command => 'lsb_release -d',
-            pattern => /Description:\s+(.+)/
+            pattern => qr/Description:\s+(.+)/
         );
     }
 
