@@ -15,14 +15,17 @@ sub doInventory {
     my (%params) = @_;
 
     my $inventory = $params{inventory};
-    my $logger    = $params{logger};
+
+    my $bios = {
+        SMANUFACTURER => 'DEC',
+    };
 
     # sysctl infos
 
     # example on *BSD: AlphaStation 255 4/232
-    my $SystemModel = getFirstLine(command => 'sysctl -n hw.model');
+    $bios->{SMODEL} = getFirstLine(command => 'sysctl -n hw.model');
 
-    my $processorn = getFirstLine(command => 'sysctl -n hw.ncpu');
+    my $count = getFirstLine(command => 'sysctl -n hw.ncpu');
 
     # dmesg infos
 
@@ -36,24 +39,18 @@ sub doInventory {
     # AlphaStation 255 4/232, 232MHz
     # CPU: EV45 (21064A) major=6 minor=2
 
-    my ($processort, $processors);
+    my $cpu;
     foreach my $line (getAllLines(command => 'dmesg')) {
-        if ($line =~ /$SystemModel,\s*(\S+)\s*MHz/) { $processors = $1; }
-        if ($line =~ /^cpu[^:]*:\s*(.*)$/i)         { $processort = $1; }
+        if ($line =~ /$bios->{SMODEL},\s*(\S+)\s*MHz/) { $cpu->{SPEED} = $1; }
+        if ($line =~ /^cpu[^:]*:\s*(.*)$/i)            { $cpu->{NAME} = $1;  }
     }
 
-    $inventory->setBios({
-        SMANUFACTURER => 'DEC',
-        SMODEL        => $SystemModel,
-    });
+    $inventory->setBios($bios);
 
-    for my $i (1 .. $processorn) {
+    while ($count--) {
         $inventory->addEntry(
             section => 'CPUS',
-            entry   => {
-                NAME  => $processort,
-                SPEED => $processors,
-            }
+            entry   => $cpu
         );
     }
 
