@@ -9,7 +9,12 @@ use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Unix;
 
 sub isEnabled {
-    return canRun('ps');
+    my (%params) = @_;
+
+    return 
+        $OSNAME ne 'MSWin32' &&
+        !$params{no_category}->{process} &&
+        canRun('ps');
 }
 
 sub doInventory {
