@@ -1,23 +1,5 @@
 package FusionInventory::Agent::Task::Inventory::Input::Generic::Screen;
-#     Copyright (C) 2005 Mandriva
-#     Copyright (C) 2007 Gonéri Le Bouder <goneri@rulezlan.org> 
-#     This program is free software; you can redistribute it and/or modify
-#     it under the terms of the GNU General Public License as published by
-#     the Free Software Foundation; either version 2 of the License, or
-#     (at your option) any later version.
 
-#     This program is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-
-#     You should have received a copy of the GNU General Public License
-#     along with this program; if not, write to the Free Software
-#     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-# Some part come from Mandriva's (great) monitor-edid
-# http://svn.mandriva.com/cgi-bin/viewvc.cgi/soft/monitor-edid/trunk/
-#
 use strict;
 use warnings;
 
@@ -25,6 +7,7 @@ use English qw(-no_match_vars);
 use MIME::Base64;
 use UNIVERSAL::require;
 
+use File::Find;
 use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Screen;
 
@@ -32,6 +15,7 @@ sub isEnabled {
 
     return
         $OSNAME eq 'MSWin32'                 ||
+        -d '/sys'                            ||
         canRun('monitor-get-edid-using-vbe') ||
         canRun('monitor-get-edid')           ||
         canRun('get-edid');
@@ -59,7 +43,9 @@ sub doInventory {
                 $screen->{SERIAL} = $edid->{serial_number2}->[0];
             }
             $screen->{BASE64} = encode_base64($screen->{edid});
+
         }
+        delete $screen->{edid};
 
         $inventory->addEntry(
             section => 'MONITORS',
@@ -71,7 +57,7 @@ sub doInventory {
 sub _getScreensFromWindows {
     my ($logger) = @_;
 
-    FusionInventory::Agent::Tools::Win32->require();
+    FusionInventory::Agent::Tools::Win32->use();
     if ($EVAL_ERROR) {
         print
             "Failed to load FusionInventory::Agent::Tools::Win32: $EVAL_ERROR";
@@ -81,25 +67,24 @@ sub _getScreensFromWindows {
     my @screens;
 
     # Vista and upper, able to get the second screen
-    foreach my $object (FusionInventory::Agent::Tools::Win32::getWmiObjects(
+    foreach my $object (getWmiObjects(
         moniker    => 'winmgmts:{impersonationLevel=impersonate,authenticationLevel=Pkt}!//./root/wmi',
         class      => 'WMIMonitorID',
         properties => [ qw/InstanceName/ ]
     )) {
         next unless $object->{InstanceName};
 
-        my $PNPDeviceID = $object->{InstanceName};
-        $PNPDeviceID =~ s/_\d+//;
+        $object->{InstanceName} =~ s/_\d+//;
         push @screens, {
-            id => $object->{PNPDeviceID}
+            id => $object->{InstanceName}
         };
     }
 
     # The generic Win32_DesktopMonitor class, the second screen will be missing
-    foreach my $object (FusionInventory::Agent::Tools::Win32::getWmiObjects(
+    foreach my $object (getWmiObjects(
         class => 'Win32_DesktopMonitor',
         properties => [ qw/
-            Caption MonitorManufacturer MonitorType PNPDeviceID
+            Caption MonitorManufacturer MonitorType PNPDeviceID Availability
         / ]
     )) {
         next unless $object->{Availability};
@@ -108,38 +93,21 @@ sub _getScreensFromWindows {
 
         push @screens, {
             id           => $object->{PNPDeviceID},
-            name         => $object->{Caption},
-            type         => $object->{MonitorType},
-            manufacturer => $object->{MonitorManufacturer},
-            caption      => $object->{Caption}
+            NAME         => $object->{Caption},
+            TYPE         => $object->{MonitorType},
+            MANUFACTURER => $object->{MonitorManufacturer},
+            CAPTION      => $object->{Caption}
         };
     }
 
-    my $Registry;
-    Win32::TieRegistry->require();
-    Win32::TieRegistry->import(
-        Delimiter   => '/',
-        ArrayValues => 0,
-        TiedRef     => \$Registry
-    );
-
     foreach my $screen (@screens) {
-
-        my $access = FusionInventory::Agent::Tools::Win32::is64bit() ?
-            Win32::TieRegistry::KEY_READ() |
-                FusionInventory::Agent::Tools::Win32::KEY_WOW64_64() :
-            Win32::TieRegistry::KEY_READ();
-
-        my $machKey = $Registry->Open('LMachine', {
-            Access => $access
-        } ) or $logger->fault(
-            "Can't open HKEY_LOCAL_MACHINE key: $EXTENDED_OS_ERROR"
-        );
-
-        $screen->{edid} =
-            $machKey->{"SYSTEM/CurrentControlSet/Enum/$screen->{id}/Device Parameters/EDID"} || '';
+        next unless $screen->{id};
+        $screen->{edid} = getRegistryValue(
+            path => "HKEY_LOCAL_MACHINE/SYSTEM/CurrentControlSet/Enum/$screen->{id}/Device Parameters/EDID",
+            logger => $logger
+        ) || '';
         $screen->{edid} =~ s/^\s+$//;
-
+        delete $screen->{id};
     }
 
     return @screens;
@@ -147,19 +115,40 @@ sub _getScreensFromWindows {
 
 sub _getScreensFromUnix {
 
-    my $raw_edid =
+    my @screens;
+
+    if (-d '/sys') {
+        my $wanted = sub {
+            return unless $File::Find::name =~ m{/edid$};
+            open my $handle, '<', $File::Find::name;
+            my $edid = <$handle>;
+            close $handle;
+
+            push @screens, { edid => $edid } if $edid;
+        };
+
+        no warnings 'File::Find';
+        File::Find::find($wanted, '/sys');
+
+        return @screens if @screens;
+    }
+
+    my $edid =
         getFirstLine(command => 'monitor-get-edid-using-vbe') ||
         getFirstLine(command => 'monitor-get-edid');
+    push @screens, { edid => $edid };
 
-    if (!$raw_edid) {
-        foreach (1..5) { # Sometime get-edid return an empty string...
-            $raw_edid = getFirstLine(command => 'get-edid');
-            last if $raw_edid && (length($raw_edid) == 128 || length($raw_edid) == 256);
+    return @screens if @screens;
+
+    foreach (1..5) { # Sometime get-edid return an empty string...
+        $edid = getFirstLine(command => 'get-edid');
+        if ($edid) {
+            push @screens, { edid => $edid };
+            last;
         }
     }
-    return unless length($raw_edid) == 128 || length($raw_edid) == 256;
 
-    return ( { edid => $raw_edid } );
+    return @screens;
 }
 
 sub _getScreens {
