@@ -32,8 +32,6 @@ sub doInventory {
 }
 
 sub _getCPUsFromProc {
-    my ($logger, $file) = @_;
-
     my $cpu = (getCPUsFromProc(@_))[0];
 
     return unless $cpu && $cpu->{'ncpus probed'};
@@ -41,7 +39,7 @@ sub _getCPUsFromProc {
     my @cpus;
     foreach (1 .. $cpu->{'ncpus probed'}) {
         push @cpus, {
-            ARCH => 'ARM',
+            ARCH => 'SPARC',
             TYPE => $cpu->{cpu},
         };
     }
