@@ -16,7 +16,7 @@ our @EXPORT = qw(
     getDevicesFromHal
     getDevicesFromProc
     getCPUsFromProc
-    getSerialnumber
+    getInfoFromSmartctl
     getInterfacesFromIfconfig
     getInterfacesFromIp
 );
@@ -24,13 +24,17 @@ our @EXPORT = qw(
 memoize('getDevicesFromUdev');
 
 sub getDevicesFromUdev {
-    my %params = @_;
+    my (%params) = @_;
 
     my @devices;
 
     foreach my $file (glob ("/dev/.udev/db/*")) {
-        next unless $file =~ /([sh]d[a-z])$/;
-        my $device = $1;
+        my $device = getFirstMatch(
+            file    => $file,
+            pattern => qr/^N:(\S+)/
+        );
+        next unless $device;
+        next unless $device =~ /([hsv]d[a-z]|sr\d+)$/;
         push (@devices, _parseUdevEntry(
                 logger => $params{logger}, file => $file, device => $device
             ));
@@ -45,7 +49,7 @@ sub getDevicesFromUdev {
 }
 
 sub _parseUdevEntry {
-    my %params = @_;
+    my (%params) = @_;
 
     my $handle = getFileHandle(%params);
     return unless $handle;
@@ -85,7 +89,7 @@ sub _parseUdevEntry {
 }
 
 sub getCPUsFromProc {
-    my %params = (
+    my (%params) = (
         file => '/proc/cpuinfo',
         @_
     );
@@ -120,7 +124,7 @@ sub _isValidCPU {
 
 
 sub getDevicesFromHal {
-    my %params = (
+    my (%params) = (
         command => '/usr/bin/lshal',
         @_
     );
@@ -164,14 +168,16 @@ sub getDevicesFromHal {
 }
 
 sub getDevicesFromProc {
-    my %params = @_;
+    my (%params) = @_;
+
+    my $logger = $params{logger};
 
     # compute list of devices
     my @names;
 
     foreach my $file (glob ("/sys/block/*")) {
-        next unless $file =~ /([sh]d[a-z]|fd\d)$/;
-        push(@names, $1);
+        next unless $file =~ /([shv]d[a-z]|fd\d)$/;
+        push @names, $1;
     }
 
     my $command = getFirstLine(command => '/sbin/fdisk -v') =~ '^GNU' ?
@@ -180,14 +186,14 @@ sub getDevicesFromProc {
 
     my $handle = getFileHandle(
         command => $command,
-        logger => $params{logger}
+        logger  => $logger
     );
 
     return unless $handle;
 
     while (my $line = <$handle>) {
-        next unless $line =~ (/^\/dev\/([sh]d[a-z])/);
-        push(@names, $1);
+        next unless $line =~ m{^/dev/([shv]d[a-z])};
+        push @names, $1;
     }
     close $handle;
 
@@ -195,28 +201,20 @@ sub getDevicesFromProc {
     my %seen;
     @names = grep { !$seen{$_}++ } @names;
 
-    # extract informations
+    # extract information
     my @devices;
     foreach my $name (@names) {
-        my $device;
-        $device->{NAME}         = $name;
-        $device->{MANUFACTURER} = _getValueFromSysProc(
-            $params{logger}, $device, 'vendor'
-        );
-        $device->{MODEL}        = _getValueFromSysProc(
-            $params{logger}, $device, 'model'
-        );
-        $device->{FIRMWARE}     = _getValueFromSysProc(
-            $params{logger}, $device, 'rev'
-        );
-        $device->{SERIALNUMBER} = _getValueFromSysProc(
-            $params{logger}, $device, 'serial'
-        );
-        $device->{TYPE}         = _getValueFromSysProc(
-            $params{logger}, $device, 'removable'
-        ) ?
-            'removable' : 'disk';
-        push (@devices, $device);
+        my $device = {
+            NAME         => $name,
+            MANUFACTURER => _getValueFromSysProc($logger, $name, 'vendor'),
+            MODEL        => _getValueFromSysProc($logger, $name, 'model'),
+            FIRMWARE     => _getValueFromSysProc($logger, $name, 'rev'),
+            SERIALNUMBER => _getValueFromSysProc($logger, $name, 'serial'),
+            TYPE         =>
+                _getValueFromSysProc($logger, $name, 'removable') ?
+                    'removable' : 'disk'
+        };
+        push @devices, $device;
     }
 
     return @devices;
@@ -225,15 +223,17 @@ sub getDevicesFromProc {
 sub _getValueFromSysProc {
     my ($logger, $device, $key) = @_;
 
+    ## no critic (ExplicitReturnUndef)
+
     my $file =
         -f "/sys/block/$device/device/$key" ? "/sys/block/$device/device/$key" :
         -f "/proc/ide/$device/$key"         ? "/proc/ide/$device/$key" :
                                               undef;
 
-    return unless $file;
+    return undef unless $file;
 
     my $handle = getFileHandle(file => $file, logger => $logger);
-    return unless $handle;
+    return undef unless $handle;
 
     my $value = <$handle>;
     close $handle;
@@ -244,21 +244,43 @@ sub _getValueFromSysProc {
     return $value;
 }
 
-sub getSerialnumber {
-    my %params = @_;
+sub getInfoFromSmartctl {
+    my (%params) = @_;
 
-    my ($serial) = getFirstMatch(
+    my $handle = getFileHandle(
+        %params,
         command => $params{device} ? "smartctl -i $params{device}" : undef,
-        file    => $params{file},
-        logger  => $params{logger},
-        pattern => qr/^Serial Number:\s+(\S*)/
     );
+    return unless $handle;
 
-    return $serial;
+    my $info = {
+        TYPE        => 'disk',
+        DESCRIPTION => 'SATA',
+    };
+
+    while (my $line = <$handle>) {
+        if ($line =~ /^Transport protocol: +(\S+)/i) {
+            $info->{DESCRIPTION} = $1;
+            next;
+        }
+
+        if ($line =~ /^Device type: +(\S+)/i) {
+            $info->{TYPE} = $1;
+            next;
+        }
+
+        if ($line =~ /^Serial number: +(\S+)/i) {
+            $info->{SERIALNUMBER} = $1;
+            next;
+        }
+    }
+    close $handle;
+
+    return $info;
 }
 
 sub getInterfacesFromIfconfig {
-    my %params = (
+    my (%params) = (
         command => '/sbin/ifconfig -a',
         @_
     );
@@ -307,7 +329,7 @@ sub getInterfacesFromIfconfig {
     return @interfaces;
 }
 sub getInterfacesFromIp {
-    my %params = (
+    my (%params) = (
         command => '/sbin/ip addr show',
         @_
     );
@@ -319,23 +341,55 @@ sub getInterfacesFromIp {
     my $interface;
 
     while (my $line = <$handle>) {
-        chomp $line;
-        if ($line =~ /^\d+:\s+(\S+): .*(UP|DOWN)/) {
-            push @interfaces, $interface if $interface;
+        if ($line =~ /^\d+:\s+(\S+): <([^>]+)>(.*)/) {
+
             $interface = {
-                DESCRIPTION => $1,
-                STATUS      => ucfirst(lc($2))
+                DESCRIPTION => $1
             };
-        } elsif ($line =~ /link\/ether ($mac_address_pattern)/) {
+
+            my $flags = $2;
+            my $remaining = $3;
+
+            if ($remaining =~ /state DOWN /) {
+                $interface->{STATUS} = 'Down';
+            } else {
+                foreach my $flag (split(/,/, $flags)) {
+                    next unless $flag eq 'UP' || $flag eq 'DOWN';
+                    $interface->{STATUS} = ucfirst(lc($flag));
+                }
+            }
+        } elsif ($line =~ /link\/\S+ ($mac_address_pattern)?/) {
             $interface->{MACADDR} = $1;
-        } elsif ($line =~ /inet6 (\S+)\//) {
-            $interface->{IPADDRESS6} = $1;
-        } elsif ($line =~ /inet ($ip_address_pattern)\/(\d{1,3})/) {
-            $interface->{IPADDRESS} = $1;
-            $interface->{IPMASK}    = getNetworkMask($1, $2);
-            $interface->{IPSUBNET}  = getSubnetAddress(
-                $interface->{IPADDRESS}, $interface->{IPMASK}
-            );
+
+            # if courrent interface is not up, there won't be any address lines
+            push @interfaces, $interface
+                unless $interface->{STATUS} && $interface->{STATUS} eq 'Up';
+        } elsif ($line =~ /inet6 (\S+)\/(\d{1,2})/) {
+            my $address = $1;
+            my $mask    = getNetworkMaskIPv6($2);
+            my $subnet  = getSubnetAddressIPv6($address, $mask);
+
+            push @interfaces, {
+                IPADDRESS6  => $address,
+                IPMASK6     => $mask,
+                IPSUBNET6   => $subnet,
+                STATUS      => $interface->{STATUS},
+                DESCRIPTION => $interface->{DESCRIPTION},
+                MACADDR     => $interface->{MACADDR}
+            };
+        } elsif ($line =~ /inet ($ip_address_pattern)(?:\/(\d{1,3}))?/) {
+            my $address = $1;
+            my $mask    = getNetworkMask($2);
+            my $subnet  = getSubnetAddress($address, $mask);
+
+            push @interfaces, {
+                IPADDRESS   => $address,
+                IPMASK      => $mask,
+                IPSUBNET    => $subnet,
+                STATUS      => $interface->{STATUS},
+                DESCRIPTION => $interface->{DESCRIPTION},
+                MACADDR     => $interface->{MACADDR}
+            };
         }
     }
 
@@ -409,9 +463,9 @@ Availables parameters:
 
 =back
 
-=head2 getSerialnumber(%params)
+=head2 getInfoFromSmartctl(%params)
 
-Returns the serial number of a drive, using smartctl.
+Returns some information about a drive, using smartctl.
 
 Availables parameters:
 
